#
# spec file for package obs-service-kiwi_metainfo_helper
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           obs-service-kiwi_metainfo_helper
Version:        0.6
Release:        9.1
Summary:        Service for substituting various variables in build recipes
License:        GPL-2.0-or-later
Group:          Development/Tools/Building
URL:            https://build.opensuse.org
Source0:        kiwi_metainfo_helper.service
Source1:        kiwi_metainfo_helper
Source2:        README
# For %%check
Source3:        test.sh
Source4:        sles-release-15.4-150400.32.2.x86_64.rpm
BuildRequires:  diffutils
Requires:       /usr/bin/find
Requires:       /usr/bin/grep
Requires:       /usr/bin/sed
BuildArch:      noarch

%description
This service can be used during buildtime to gain access to various variables
in build recipes.

%prep
%setup -q -D -T -c
cp %{SOURCE2} .

%build

%install
mkdir -p %{buildroot}%{_prefix}/lib/obs/service/
install -m 0644 %{SOURCE0} %{buildroot}%{_prefix}/lib/obs/service/
install -m 0755 %{SOURCE1} %{buildroot}%{_prefix}/lib/obs/service/

%check
sh %{SOURCE3}

%files
%doc README
%dir %{_prefix}/lib/obs
%{_prefix}/lib/obs/service

%changelog
* Wed May  7 2025 Dirk Müller <dmueller@suse.com>
- add %%SOURCEURL_WITH%% for proper handling of READMEs
* Mon Apr  7 2025 Ladislav Slezák <lslezak@suse.com>
- Do the replacements also in the "config.sh" file in Kiwi builds
  (bsc#1240886)
* Mon Sep 30 2024 Dirk Müller <dmueller@suse.com>
- don't replace %%BASE_DIGEST%% with empty string when not available
* Wed Sep 25 2024 Fabian Vogt <fvogt@suse.com>
- Small cleanups:
  * Pass --quiet to cpio
  * Use consistent variable name for REGISTRY_DIGEST
  * Mention %%BASE_*%% behaviour for multi-stage builds explicitly
* Thu Aug  8 2024 Dirk Müller <dmueller@suse.com>
- add substitutions for base image references and digests
  (jsc#PED-8543)
* Fri Jun  7 2024 Andrea Mazzotti <andrea.mazzotti@suse.com>
- Support Docker.FLAVOR in _multibuild (boo#1226010)
* Thu Feb  1 2024 Marina Latini <marina.latini@suse.com>
- Replace %%ARCH%% with the architecture in images for supporting
  subscriptions in SCC based on architectures
* Fri Sep 15 2023 Michal Suchanek <msuchanek@suse.com>
- cpio on SLE12 does not support -D option, emulate it.
* Tue Dec  6 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Do not ever use "%%setup -n .": rpm 4.18 tries to be cleaner and
  remove stuff it extraced, which would lead to 'rm -rf .', which
  rm does not like. Use "%%setup -c" instead, which creates the
  appropriate %%{name}-%%{version} directory expected.
* Tue Feb 15 2022 Frederic Crozat <fcrozat@suse.com>
- Generate OS_VERSION_NO_DASH based on os-release VERSION,
  as workaround to replace dash with space in OS name
  (bsc#1195061).
- Bump version to 0.6
* Tue Feb  8 2022 Frederic Crozat <fcrozat@suse.com>
- Improve examples in README.
* Mon Jan 24 2022 Frederic Crozat <fcrozat@suse.com>
- Generate OS_VERSION based on os-release VERSION (bsc#1195061).
- Bump version to 0.5
* Mon Jan 17 2022 Fabian Vogt <fvogt@suse.com>
- Add test suite (test.sh, sles-release-15.4-150400.32.2.x86_64.rpm)
- Fix SOURCEURL for multibuild DISTURLs
- Set SOURCEURL also in chroot builds
* Thu Jan 13 2022 Frederic Crozat <fcrozat@suse.com>
- Generate SOURCEURL based on DISTURL.
- Bump version to 0.4
* Wed Jun  2 2021 Jeff Kowalczyk <jkowalczyk@suse.com>
- Provide various modified spellings of PRETTY_NAME useful for
  writing KIWI image definitions with reduced diff between SLE,
  Leap and Tumbleweed. DASHED satisfies the requirement that kiwi
  image names must not have spaces. The BEFORE_PAREN variations
  drop the release label in parentheses (SLE only) and can be used
  as a stable name for image registries and WSL app store
  submissions.
  * VENDOR
  * PRETTY_NAME_DASHED
  * PRETTY_NAME_BEFORE_PAREN
  * PRETTY_NAME_BEFORE_PAREN_DASHED
  (Needed for jsc#SLE-12986)
- Update README and service definition XML to reflect all variables
- Bump version to 0.3
* Mon Feb  1 2021 Fabian Vogt <fvogt@suse.com>
- Don't enable pipefail: rpm got SIGPIPE because grep -q exits early
  and closes the other end, which made the whole expression fail
* Wed Jan 27 2021 Fabian Vogt <fvogt@suse.com>
- Read os-release from the to be installed RPMs. This avoids pulling
  in distribution-release when not necessary (boo#1180263)
- Bump version to 0.2
* Tue Sep  1 2020 Fabian Vogt <fvogt@suse.com>
- Use a boolean dep to avoid use of %%{is_opensuse}. The prjconf
  selects which one to use this way.
- Bump version to 0.1
* Thu Aug 27 2020 Fabian Vogt <fvogt@suse.com>
- Fix grammar, update README and .service. Technically the name
  should be changed as well, but that's just cosmetic.
* Tue Aug 25 2020 Stefan Nica <snica@suse.com>
- Also allow working on Chart.yaml (jsc#CAPS-5)
* Tue Jul  7 2020 Fabian Vogt <fvogt@suse.com>
- Add explicit fallback for chroot builds
- Refactor into a single sed call
* Tue May  5 2020 Fabian Vogt <fvogt@suse.com>
- Also allow working on Dockerfile (jsc#CAPS-10)
* Mon May  4 2020 Fabian Vogt <fvogt@suse.com>
- Strip service prefix from the recipe name to work with enabled
  services in OBS
* Thu Jan 10 2019 Fabian Vogt <fvogt@suse.com>
- Add %%OS_VERSION_ID(_SP)%% and %%PRETTY_NAME%% (boo#1119378)
* Thu Jan 10 2019 Fabian Vogt <fvogt@suse.com>
- Remove spurious parameter to %%setup -T
- Mention that it's a service in the summary
* Wed Oct 17 2018 Fabian Vogt <fvogt@suse.com>
- Initial commit (fate#326856, bsc#1118103)
